(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    103178,       1919]
NotebookOptionsPosition[    103601,       1911]
NotebookOutlinePosition[    104036,       1930]
CellTagsIndexPosition[    103993,       1927]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Combined Loadings", "Title",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 TextAlignment->Center,
 ExpressionUUID -> "d890e306-93c5-4bdb-a099-038368ecbb65"],

Cell["\<\
Based on the example 8.5 of R. C. Hibbeler\[CloseCurlyQuote]s Mechanics of \
Materials, 10th edition\
\>", "Text",
 TextAlignment->Center],

Cell[TextData[StyleBox["Qingchang Liu, Baoxing Xu \nUniversity of Virginia, \
2018-03-30",
 FontColor->GrayLevel[0]]], "Text",
 TextAlignment->Center],

Cell["\<\
The solid rod shown below is fixed on the wall at one end and applied with a \
force at the other end. The module is designed to show how to determine the \
internal loading and stress on a chosen section A. \
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{CloudObject`Private`cub$$ = 0, CloudObject`Private`df$$ =
     30, CloudObject`Private`inf$$ = 0, CloudObject`Private`lac$$ = 0.5, 
    CloudObject`Private`lbd$$ = 1, CloudObject`Private`lcd$$ = 1, 
    CloudObject`Private`mf$$ = 500, CloudObject`Private`R$$ = 0.05, 
    CloudObject`Private`reset$$ = False, CloudObject`Private`sup$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[CloudObject`Private`lcd$$], 1, 
       Row[{"Length of CD [m]", 
         Spacer[60]}]}, 0.5, 2}, {{
       Hold[CloudObject`Private`lbd$$], 1, 
       Row[{"Length of BD [m]", 
         Spacer[60]}]}, 0.01, 2}, {{
       Hold[CloudObject`Private`R$$], 0.05, 
       Row[{"Radius of the rod [m]", 
         Spacer[40]}]}, 0.05, 0.1}, {{
       Hold[CloudObject`Private`mf$$], 500, 
       Row[{"Magnitude of Force[N]", 
         Spacer[30]}]}, 0.1, 500}, {{
       Hold[CloudObject`Private`df$$], 30, 
       Row[{"Direction of Force", 
         Spacer[55]}]}, -180, 180}, {{
       Hold[CloudObject`Private`lac$$], 0.5, 
       Row[{"Position of Point A [m]", 
         Spacer[30]}]}, 0, 
      Dynamic[0.99 CloudObject`Private`lcd$$]}, {{
       Hold[CloudObject`Private`inf$$], 0, 
       Row[{"Internal Loadings on Section A", 
         Spacer[52]}]}, {1 -> "On", 0 -> "off"}}, {{
       Hold[CloudObject`Private`sup$$], 0, 
       Row[{"Decomposed Stress on Section A", 
         Spacer[40]}]}, {1 -> "On", 0 -> "off"}}, {{
       Hold[CloudObject`Private`cub$$], 0, 
       Row[{"Stress Cubic at Point A", 
         Spacer[95]}]}, {1 -> "On", 0 -> "off"}}, {
      Hold[
       Grid[{{
          Row[{
            Column[{
              Manipulate`Place[1], 
              Manipulate`Place[2], 
              Manipulate`Place[3]}], 
            Spacer[50], 
            Column[{
              Manipulate`Place[4], 
              Manipulate`Place[5], 
              Manipulate`Place[6]}], 
            Spacer[50], 
            Column[{
              Manipulate`Place[7], 
              Manipulate`Place[8], 
              Manipulate`Place[9]}], 
            Spacer[50], 
            Column[{
              Button[
              "Reset view", CloudObject`Private`reset$$ = True, 
               ImageSize -> {90, 30}]}]}]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[CloudObject`Private`reset$$], False}, 0}}, Typeset`size$$ = {
    450., {230.5, 236.5}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, CloudObject`Private`lcd$82126$$ = 0, 
    CloudObject`Private`lbd$82127$$ = 0, CloudObject`Private`R$82128$$ = 0, 
    CloudObject`Private`mf$82129$$ = 0, CloudObject`Private`df$82130$$ = 0, 
    CloudObject`Private`lac$82131$$ = 0, CloudObject`Private`inf$82132$$ = 
    False, CloudObject`Private`sup$82133$$ = False, 
    CloudObject`Private`cub$82134$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {
       CloudObject`Private`cub$$ = 0, CloudObject`Private`df$$ = 30, 
        CloudObject`Private`inf$$ = 0, CloudObject`Private`lac$$ = 0.5, 
        CloudObject`Private`lbd$$ = 1, CloudObject`Private`lcd$$ = 1, 
        CloudObject`Private`mf$$ = 500, CloudObject`Private`R$$ = 0.05, 
        CloudObject`Private`reset$$ = False, CloudObject`Private`sup$$ = 0}, 
      "ControllerVariables" :> {
        Hold[CloudObject`Private`lcd$$, CloudObject`Private`lcd$82126$$, 0], 
        Hold[CloudObject`Private`lbd$$, CloudObject`Private`lbd$82127$$, 0], 
        Hold[CloudObject`Private`R$$, CloudObject`Private`R$82128$$, 0], 
        Hold[CloudObject`Private`mf$$, CloudObject`Private`mf$82129$$, 0], 
        Hold[CloudObject`Private`df$$, CloudObject`Private`df$82130$$, 0], 
        Hold[CloudObject`Private`lac$$, CloudObject`Private`lac$82131$$, 0], 
        Hold[
        CloudObject`Private`inf$$, CloudObject`Private`inf$82132$$, False], 
        Hold[
        CloudObject`Private`sup$$, CloudObject`Private`sup$82133$$, False], 
        Hold[
        CloudObject`Private`cub$$, CloudObject`Private`cub$82134$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{CloudObject`Private`size$, CloudObject`Private`R0$, 
         CloudObject`Private`Iz$, CloudObject`Private`A$, 
         CloudObject`Private`lac0$, CloudObject`Private`sita$, 
         CloudObject`Private`fy$, CloudObject`Private`fz$, 
         CloudObject`Private`bendmomentfy$, CloudObject`Private`bendmomentfz$,
          CloudObject`Private`bendmoment$, 
         CloudObject`Private`bendmomentangle$, CloudObject`Private`torque$, 
         CloudObject`Private`tensionnormal$, 
         CloudObject`Private`tensionbendmax$, 
         CloudObject`Private`forcefactor$, CloudObject`Private`bendshear$, 
         CloudObject`Private`sign$, CloudObject`Private`show$, 
         CloudObject`Private`pd$, CloudObject`Private`nd$, 
         CloudObject`Private`settings1$, CloudObject`Private`settings2$, 
         CloudObject`Private`settings3$, CloudObject`Private`settings4$, 
         CloudObject`Private`settings5$, CloudObject`Private`settings6$, 
         CloudObject`Private`settings7$, CloudObject`Private`settings8$, 
         CloudObject`Private`view1$, CloudObject`Private`view2$, 
         CloudObject`Private`dwf1$, CloudObject`Private`dwf2$, 
         CloudObject`Private`dwf3$, CloudObject`Private`dwf4$, 
         CloudObject`Private`dwf5$, CloudObject`Private`dwf6$, 
         CloudObject`Private`dwf7$, CloudObject`Private`dwf8$, 
         CloudObject`Private`dwf9$, CloudObject`Private`dwf10$, 
         CloudObject`Private`dwf11$, CloudObject`Private`dwf12$, 
         CloudObject`Private`dwf13$, CloudObject`Private`dwf14$, 
         CloudObject`Private`dwf15$, CloudObject`Private`dw1$, 
         CloudObject`Private`dw2$, CloudObject`Private`dw3$, 
         CloudObject`Private`dw4$, CloudObject`Private`dw5$, 
         CloudObject`Private`dw6$, CloudObject`Private`dw7$, 
         CloudObject`Private`dw8$, CloudObject`Private`dw9$, 
         CloudObject`Private`dw10$}, CloudObject`Private`patompa = 1000000; 
        CloudObject`Private`size$ = CloudObject`Private`lcd$$; 
        CloudObject`Private`R0$ = 0.1; 
        CloudObject`Private`Iz$ = ((((Pi CloudObject`Private`R$$) 
             CloudObject`Private`R$$) CloudObject`Private`R$$) 
           CloudObject`Private`R$$)/4; 
        CloudObject`Private`J = 2 CloudObject`Private`Iz$; 
        CloudObject`Private`A$ = (Pi CloudObject`Private`R$$) 
          CloudObject`Private`R$$; CloudObject`Private`lac0$ = 0.1; 
        CloudObject`Private`sita$ = (CloudObject`Private`df$$/180) Pi; 
        CloudObject`Private`fy$ = 
         CloudObject`Private`mf$$ Cos[CloudObject`Private`sita$]; 
        CloudObject`Private`fyfactor = 2200; 
        CloudObject`Private`fz$ = 
         CloudObject`Private`mf$$ Sin[CloudObject`Private`sita$]; 
        CloudObject`Private`bendmomentfy$ = 
         CloudObject`Private`fy$ CloudObject`Private`lbd$$; 
        CloudObject`Private`bendmomentfz$ = 
         CloudObject`Private`fz$ (CloudObject`Private`lcd$$ - 
           CloudObject`Private`lac$$); 
        CloudObject`Private`bendmoment$ = 
         Sqrt[CloudObject`Private`bendmomentfy$^2 + 
           CloudObject`Private`bendmomentfz$^2]; 
        CloudObject`Private`bendmomentmax = 1000; 
        CloudObject`Private`bendmomentfyratio = 
         Abs[CloudObject`Private`bendmomentfy$/
           CloudObject`Private`bendmomentmax]; 
        CloudObject`Private`bendmomentfzratio = 
         Abs[CloudObject`Private`bendmomentfz$/
           CloudObject`Private`bendmomentmax]; 
        CloudObject`Private`xportionmoment = 
         If[Abs[CloudObject`Private`bendmoment$] > 0, 
           CloudObject`Private`bendmomentfz$/CloudObject`Private`bendmoment$]; 
        CloudObject`Private`zportionmoment = 
         If[
          Abs[CloudObject`Private`bendmoment$] > 0, 
           CloudObject`Private`bendmomentfy$/CloudObject`Private`bendmoment$]; 
        CloudObject`Private`xportionstress = 
         If[Abs[CloudObject`Private`bendmoment$] > 
           0, (-CloudObject`Private`bendmomentfy$)/
           CloudObject`Private`bendmoment$]; 
        CloudObject`Private`zportionstress = 
         If[Abs[CloudObject`Private`bendmoment$] > 0, 
           CloudObject`Private`bendmomentfz$/CloudObject`Private`bendmoment$]; 
        CloudObject`Private`torque$ = 
         CloudObject`Private`fz$ CloudObject`Private`lbd$$; 
        CloudObject`Private`torquemax = 1000; 
        CloudObject`Private`torqueratio = 
         Abs[CloudObject`Private`torque$/CloudObject`Private`torquemax]; 
        CloudObject`Private`tensionnormal$ = (CloudObject`Private`fy$/
           CloudObject`Private`A$)/CloudObject`Private`patompa; 
        CloudObject`Private`tensionbendmax$ = 
         CloudObject`Private`bendmoment$ ((CloudObject`Private`R$$/
            CloudObject`Private`Iz$)/CloudObject`Private`patompa); 
        CloudObject`Private`tensionbendfy = 
         CloudObject`Private`bendmomentfy$ ((CloudObject`Private`R$$/
            CloudObject`Private`Iz$)/CloudObject`Private`patompa); 
        CloudObject`Private`shearbend = (CloudObject`Private`fz$/
           CloudObject`Private`A$)/CloudObject`Private`patompa; 
        CloudObject`Private`sheartorsion = (CloudObject`Private`torque$/
           CloudObject`Private`J)/CloudObject`Private`patompa; 
        CloudObject`Private`forcefactor$ = 250000/CloudObject`Private`patompa; 
        CloudObject`Private`normalbendfactor = 
         20000000/CloudObject`Private`patompa; 
        CloudObject`Private`shearbendfactor = 
         300000/CloudObject`Private`patompa; 
        CloudObject`Private`sheartorsionfactor = 
         400000000/CloudObject`Private`patompa; 
        CloudObject`Private`bendshear$ = (CloudObject`Private`fz$/
           CloudObject`Private`A$)/CloudObject`Private`patompa; 
        CloudObject`Private`normalstress = 
         CloudObject`Private`tensionnormal$ + 
          CloudObject`Private`tensionbendfy; 
        CloudObject`Private`shearstress = 
         CloudObject`Private`shearbend + CloudObject`Private`sheartorsion; 
        CloudObject`Private`normalfactor = 
         50000000/CloudObject`Private`patompa; 
        CloudObject`Private`shearfactor = 
         400000000/CloudObject`Private`patompa; 
        CloudObject`Private`reset1 = 
         If[CloudObject`Private`reset$$, CloudObject`Private`reset$$ = False; 
           False, True]; 
        CloudObject`Private`view1$ = {(0.7 100) 
           CloudObject`Private`size$, (0.7 100) CloudObject`Private`size$, 
           100 CloudObject`Private`size$}; 
        CloudObject`Private`view2$ = {(0.7 100) 
           CloudObject`Private`size$, (0.7 100) CloudObject`Private`size$, 
           100 CloudObject`Private`size$}; 
        CloudObject`Private`settings1$ = {
          Boxed -> False, SphericalRegion -> True, 
           PlotRange -> {{-0.5, 2.1}, {-0.1, 2.5}, {-1, 1}}, ViewPoint -> 
           CloudObject`Private`view1$, ImageSize -> 450}; 
        CloudObject`Private`settings2$ = {
          Boxed -> False, SphericalRegion -> True, 
           PlotRange -> {{(-1.25) CloudObject`Private`R0$ - 1, 
              1.25 CloudObject`Private`R0$ - 1}, {
             0, CloudObject`Private`lac0$ + 
              0.4}, {(-1.25) CloudObject`Private`R0$ - 1, 
              1.25 CloudObject`Private`R0$ - 1}}, ViewPoint -> 
           CloudObject`Private`view2$, ImageSize -> 200}; 
        CloudObject`Private`settings3$ = {
          Boxed -> False, SphericalRegion -> True, 
           PlotRange -> {{(-1.25) CloudObject`Private`R0$ - 1, 
              1.25 CloudObject`Private`R0$ - 1}, {
             0, CloudObject`Private`lac0$ + 
              0.4}, {(-1.25) CloudObject`Private`R0$ - 2, 
              1.25 CloudObject`Private`R0$ - 2}}, ViewPoint -> 
           CloudObject`Private`view2$, ImageSize -> 215}; 
        CloudObject`Private`settings4$ = {
          Boxed -> False, SphericalRegion -> True, 
           PlotRange -> {{(-1.25) CloudObject`Private`R0$ - 1.5, 
              1.25 CloudObject`Private`R0$ - 1.5}, {
             0.5, CloudObject`Private`lac0$ + 0.5 + 
              0.4}, {(-1.25) CloudObject`Private`R0$ - 2.2, 
              1.25 CloudObject`Private`R0$ - 2.2}}, ViewPoint -> 
           CloudObject`Private`view2$, ImageSize -> 205}; 
        CloudObject`Private`settings5$ = {
          Boxed -> False, SphericalRegion -> True, 
           PlotRange -> {{(-1.25) CloudObject`Private`R0$ - 2, 
              1.25 CloudObject`Private`R0$ - 2}, {
             1, CloudObject`Private`lac0$ + 1 + 
              0.4}, {(-1.25) CloudObject`Private`R0$ - 2.4, 
              1.25 CloudObject`Private`R0$ - 2.4}}, ViewPoint -> 
           CloudObject`Private`view2$, ImageSize -> 230}; 
        CloudObject`Private`settings6$ = {
          Boxed -> False, SphericalRegion -> True, 
           PlotRange -> {{(-1.25) CloudObject`Private`R0$ - 2.5, 
              1.25 CloudObject`Private`R0$ - 2.5}, {
             1.5, CloudObject`Private`lac0$ + 1.5 + 
              0.4}, {(-1.25) CloudObject`Private`R0$ - 2.6, 
              1.25 CloudObject`Private`R0$ - 2.6}}, ViewPoint -> 
           CloudObject`Private`view2$, ImageSize -> 200}; 
        CloudObject`Private`settings7$ = {
          Boxed -> False, SphericalRegion -> True, 
           PlotRange -> {{(-3) CloudObject`Private`R0$, 3 
              CloudObject`Private`R0$}, {(-3) CloudObject`Private`R0$, 3 
              CloudObject`Private`R0$}}, ImageSize -> 250}; 
        CloudObject`Private`settings8$ = {
          Boxed -> False, SphericalRegion -> True, 
           PlotRange -> {{(-4) CloudObject`Private`R0$, 4 
              CloudObject`Private`R0$}, {(-4) CloudObject`Private`R0$, 4 
              CloudObject`Private`R0$}}, ImageSize -> 250}; 
        CloudObject`Private`dwf1$ = {
           Opacity[1], 
           Dashing[{}], 
           Thickness[0.002], 
           Arrowheads[0.03], 
           Arrow[{{0, 0, 0}, {5 CloudObject`Private`R0$, 0, 0}}], 
           
           Arrow[{{0, 0, 0}, {
             0, CloudObject`Private`lcd$$ + 5 CloudObject`Private`R0$, 0}}], 
           Arrow[{{0, 0, 0}, {0, 0, 5 CloudObject`Private`R0$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {5.5 CloudObject`Private`R0$, 0, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0, CloudObject`Private`lcd$$ + 6 CloudObject`Private`R0$, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {0, 0, 5.5 CloudObject`Private`R0$}]}; 
        CloudObject`Private`dwf2$ = {
           Opacity[0.8], LightGray, 
           
           Cuboid[{(-1.5) CloudObject`Private`R0$, (-0.1) 
             CloudObject`Private`R0$, (-1.5) CloudObject`Private`R0$}, {
            1.5 CloudObject`Private`R0$, 0, 1.5 CloudObject`Private`R0$}]}; 
        CloudObject`Private`dwf3$ = {
           Opacity[1], LightBlue, 
           
           Cylinder[{{0, 0, 0}, {0, CloudObject`Private`lcd$$, 0}}, 
            CloudObject`Private`R$$], Black, 
           Text["C", {(-3.5) CloudObject`Private`R0$, 0, 0}], 
           
           Line[{{-CloudObject`Private`R$$, 0, 0}, {(-3) 
              CloudObject`Private`R0$, 0, 0}}], 
           
           Line[{{-CloudObject`Private`R$$, CloudObject`Private`lcd$$, 
              0}, {(-3) CloudObject`Private`R0$, CloudObject`Private`lcd$$, 
              0}}], 
           Arrowheads[0.025], 
           
           Arrow[{{(-2.5) CloudObject`Private`R0$, 0, 0}, {(-2.5) 
              CloudObject`Private`R0$, CloudObject`Private`lcd$$, 0}}], 
           
           Arrow[{{(-2.5) CloudObject`Private`R0$, CloudObject`Private`lcd$$, 
              0}, {(-2.5) CloudObject`Private`R0$, 0, 0}}]}; 
        CloudObject`Private`dwf4$ = {
           Opacity[1], LightBlue, 
           
           Cylinder[{{0, CloudObject`Private`lcd$$, 0}, {
             CloudObject`Private`lbd$$, CloudObject`Private`lcd$$, 0}}, 
            CloudObject`Private`R$$], Black, 
           Text[
           "B", {CloudObject`Private`lbd$$, CloudObject`Private`lcd$$ + 
             3.5 CloudObject`Private`R0$, 0}], 
           
           Line[{{CloudObject`Private`lbd$$, CloudObject`Private`lcd$$, 0}, {
             CloudObject`Private`lbd$$, CloudObject`Private`lcd$$ + 
              3 CloudObject`Private`R0$, 0}}], 
           Arrowheads[0.025], 
           
           Arrow[{{CloudObject`Private`lbd$$, CloudObject`Private`lcd$$ + 
              3 CloudObject`Private`R0$, 0}, {
             0, CloudObject`Private`lcd$$ + 3 CloudObject`Private`R0$, 0}}], 
           
           Arrow[{{0, CloudObject`Private`lcd$$ + 3 CloudObject`Private`R0$, 
              0}, {CloudObject`Private`lbd$$, CloudObject`Private`lcd$$ + 
              3 CloudObject`Private`R0$, 0}}]}; CloudObject`Private`dwf5$ = {
           Opacity[1], LightBlue, 
           Sphere[{0, CloudObject`Private`lcd$$, 0}, CloudObject`Private`R$$],
            Black, 
           Text[
           "D", {(-3.5) CloudObject`Private`R0$, CloudObject`Private`lcd$$, 
             0}]}; CloudObject`Private`dwf6$ = {
           Opacity[1], Red, 
           PointSize[0.02], 
           Point[{CloudObject`Private`R$$, CloudObject`Private`lac$$, 0}], 
           Text[
           "A", {3 CloudObject`Private`R$$, CloudObject`Private`lac$$, 0}], 
           Black, 
           
           Line[{{-CloudObject`Private`R$$, CloudObject`Private`lac$$, 
              0}, {(-3) CloudObject`Private`R0$, CloudObject`Private`lac$$, 
              0}}], 
           Arrowheads[0.025], 
           
           Arrow[{{(-2.5) CloudObject`Private`R0$, 0, 0}, {(-2.5) 
              CloudObject`Private`R0$, CloudObject`Private`lac$$, 0}}], 
           
           Arrow[{{(-2.5) CloudObject`Private`R0$, CloudObject`Private`lcd$$, 
              0}, {(-2.5) CloudObject`Private`R0$, CloudObject`Private`lac$$, 
              0}}]}; CloudObject`Private`dwf7$ = {
           Opacity[1], Red, 
           Arrowheads[0.04], 
           Thickness[0.005], 
           
           Arrow[{{CloudObject`Private`lbd$$, CloudObject`Private`lcd$$, 0}, {
             CloudObject`Private`lbd$$, 
              CloudObject`Private`lcd$$ + (CloudObject`Private`mf$$/900) 
               Cos[CloudObject`Private`sita$], (CloudObject`Private`mf$$/900) 
              Sin[CloudObject`Private`sita$]}}], 
           Text[
           "F", {CloudObject`Private`lbd$$, 
             CloudObject`Private`lcd$$ + (CloudObject`Private`mf$$/850) 
              Cos[CloudObject`Private`sita$], (CloudObject`Private`mf$$/850) 
             Sin[CloudObject`Private`sita$]}]}; CloudObject`Private`dwf8$ = {
           Opacity[CloudObject`Private`inf$$], LightBlue, 
           
           Cylinder[{{0, 0, 0} + {-1, 0, -1}, {
              0, CloudObject`Private`lac0$, 0} + {-1, 0, -1}}, 
            CloudObject`Private`R0$], Black, 
           PointSize[0.05], 
           
           Point[{CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-1, 0, -1}], 
           Text[
           "A", {2 CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-1, 0, -1}], Red, 
           Arrowheads[0.075], 
           Thickness[0.015], 
           If[CloudObject`Private`fy$ > 0, 
            
            Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1, 0, -1}, {
               0, CloudObject`Private`lac0$, 0} + {-1, 0, -1} + {
               0, CloudObject`Private`fy$/CloudObject`Private`fyfactor, 0}}], 
            
            Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1, 0, -1} - {
              0, CloudObject`Private`fy$/CloudObject`Private`fyfactor, 0}, {
               0, CloudObject`Private`lac0$, 0} + {-1, 0, -1}}]], Green, 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-1, 0, -1} - {
             0, 0, (CloudObject`Private`fz$/2)/
              CloudObject`Private`fyfactor}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-1, 0, -1} + {
              0, 0, (CloudObject`Private`fz$/2)/
               CloudObject`Private`fyfactor}}], Purple, 
           If[CloudObject`Private`fz$ > 0, 
            
            Cone[{{(CloudObject`Private`R0$ CloudObject`Private`torqueratio) 
                Cos[Pi/1.2 - Pi/4], 
                0, (CloudObject`Private`R0$ CloudObject`Private`torqueratio) 
                Sin[Pi/1.2 - Pi/4]} + {-1, 0, -1} + {
               0, 2 CloudObject`Private`lac0$, 
                0}, {(CloudObject`Private`R0$ CloudObject`Private`torqueratio)
                  Cos[Pi/1.2], 
                0, (CloudObject`Private`R0$ CloudObject`Private`torqueratio) 
                Sin[Pi/1.2]} + {-1, 0, -1} + {
               0, 2 CloudObject`Private`lac0$, 0}}, 
             CloudObject`Private`R0$ (CloudObject`Private`torqueratio/5)], 
            
            Cone[{{(CloudObject`Private`R0$ CloudObject`Private`torqueratio) 
                Cos[((-Pi)/1.2) (Plus[Pi]/4)], 
                0, (CloudObject`Private`R0$ CloudObject`Private`torqueratio) 
                Sin[((-Pi)/1.2) (Plus[Pi]/4)]} + {-1, 0, -1} + {
               0, 2 CloudObject`Private`lac0$, 
                0}, {(CloudObject`Private`R0$ CloudObject`Private`torqueratio)
                  Cos[(-Pi)/1.2], 
                0, (CloudObject`Private`R0$ CloudObject`Private`torqueratio) 
                Sin[(-Pi)/1.2]} + {-1, 0, -1} + {
               0, 2 CloudObject`Private`lac0$, 0}}, 
             CloudObject`Private`R0$ (CloudObject`Private`torqueratio/5)]], 
           Arrowheads[0.05], Blue, 
           If[CloudObject`Private`fy$ > 0, 
            
            Arrow[{{(0.75 CloudObject`Private`R0$) 
                Cos[Pi/2 + Pi (CloudObject`Private`bendmomentfyratio/1.2) - 
                  Pi/8], (0.75 CloudObject`Private`R0$) 
                Sin[Pi/2 + Pi (CloudObject`Private`bendmomentfyratio/1.2) - 
                  Pi/8], 0} + {-1, 0, -1} + {
               0, 3 CloudObject`Private`lac0$, 
                0}, {(0.75 CloudObject`Private`R0$) 
                Cos[Pi/2 + Pi (CloudObject`Private`bendmomentfyratio/1.2)], (
                 0.75 CloudObject`Private`R0$) 
                Sin[Pi/2 + Pi (CloudObject`Private`bendmomentfyratio/1.2)], 
                0} + {-1, 0, -1} + {0, 3 CloudObject`Private`lac0$, 0}}], 
            
            Arrow[{{(0.75 CloudObject`Private`R0$) 
                Cos[Pi/2 - Pi (CloudObject`Private`bendmomentfyratio/1.2) + 
                  Pi/8], (0.75 CloudObject`Private`R0$) 
                Sin[Pi/2 - Pi (CloudObject`Private`bendmomentfyratio/1.2) + 
                  Pi/8], 0} + {-1, 0, -1} + {
               0, 3 CloudObject`Private`lac0$, 
                0}, {(0.75 CloudObject`Private`R0$) 
                Cos[Pi/2 - Pi (CloudObject`Private`bendmomentfyratio/1.2)], (
                 0.75 CloudObject`Private`R0$) 
                Sin[Pi/2 - Pi (CloudObject`Private`bendmomentfyratio/1.2)], 
                0} + {-1, 0, -1} + {0, 3 CloudObject`Private`lac0$, 0}}]], 
           Blue, 
           If[CloudObject`Private`fz$ > 0, 
            
            Arrow[{{0, (0.75 CloudObject`Private`R0$) 
                Cos[Pi (CloudObject`Private`bendmomentfzratio/1.2) - Pi/8], (
                 0.75 CloudObject`Private`R0$) 
                Sin[Pi (CloudObject`Private`bendmomentfzratio/1.2) - Pi/
                  8]} + {-1, 0, -1} + {0, 4 CloudObject`Private`lac0$, 0}, {
               0, (0.75 CloudObject`Private`R0$) 
                Cos[Pi (CloudObject`Private`bendmomentfzratio/1.2)], (0.75 
                 CloudObject`Private`R0$) 
                Sin[Pi (CloudObject`Private`bendmomentfzratio/1.2)]} + {-1, 
               0, -1} + {0, 4 CloudObject`Private`lac0$, 0}}], 
            
            Arrow[{{0, (0.75 CloudObject`Private`R0$) 
                Cos[(-Pi) (CloudObject`Private`bendmomentfzratio/1.2) + 
                  Pi/8], (0.75 CloudObject`Private`R0$) 
                Sin[(-Pi) (CloudObject`Private`bendmomentfzratio/1.2) + 
                  Pi/8]} + {-1, 0, -1} + {
               0, 4 CloudObject`Private`lac0$, 0}, {
               0, (0.75 CloudObject`Private`R0$) 
                Cos[(-Pi) (CloudObject`Private`bendmomentfzratio/1.2)], (0.75 
                 CloudObject`Private`R0$) 
                Sin[(-Pi) (CloudObject`Private`bendmomentfzratio/1.2)]} + {-1,
                0, -1} + {0, 4 CloudObject`Private`lac0$, 0}}]], Black, 
           Dashed, 
           Thickness[0.01], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-1, 0, -1} - {
             CloudObject`Private`R0$, 0, 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1, 0, -1} + {
              CloudObject`Private`R0$, 0, 0}}], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-1, 0, -1} - {
             0, 0, CloudObject`Private`R0$}, {
              0, CloudObject`Private`lac0$, 0} + {-1, 0, -1} + {
              0, 0, CloudObject`Private`R0$}}]}; CloudObject`Private`dwf10$ = {
           Opacity[CloudObject`Private`inf$$ CloudObject`Private`sup$$], 
           LightGray, 
           
           Cylinder[{{0, 0, 0} + {-1, 0, -2}, {
              0, CloudObject`Private`lac0$, 0} + {-1, 0, -2}}, 
            CloudObject`Private`R0$], Black, 
           PointSize[0.05], 
           
           Point[{CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-1, 0, -2}], 
           Text[
           "A", {2 CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-1, 0, -2}], 
           Text[
           "Normal Stress Due to Axial Loading", {
             0, CloudObject`Private`lac0$, 2 CloudObject`Private`R0$} + {-1, 
             0, -2}], Red, 
           Arrowheads[0.05], 
           Thickness[0.01], 
           If[CloudObject`Private`tensionnormal$ > 0, 
            
            Arrow[{{CloudObject`Private`R0$, CloudObject`Private`lac0$, 
                0} + {-1, 0, -2}, {
               CloudObject`Private`R0$, CloudObject`Private`lac0$, 0} + {-1, 
               0, -2} + {0, 1, 0} (CloudObject`Private`tensionnormal$/
                CloudObject`Private`forcefactor$)}], 
            
            Arrow[{{CloudObject`Private`R0$, CloudObject`Private`lac0$, 
                0} + {-1, 0, -2} - {0, 1, 0} (
               CloudObject`Private`tensionnormal$/
               CloudObject`Private`forcefactor$), {
               CloudObject`Private`R0$, CloudObject`Private`lac0$, 0} + {-1, 
               0, -2}}]], 
           If[CloudObject`Private`tensionnormal$ > 0, 
            
            Arrow[{{CloudObject`Private`R0$ Cos[Pi/2], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[Pi/2]} + {-1, 0, -2}, {
               CloudObject`Private`R0$ Cos[Pi/2], CloudObject`Private`lac0$, 
                CloudObject`Private`R0$ Sin[Pi/2]} + {-1, 
               0, -2} + {0, 1, 0} (CloudObject`Private`tensionnormal$/
                CloudObject`Private`forcefactor$)}], 
            
            Arrow[{{CloudObject`Private`R0$ Cos[Pi/2], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[Pi/2]} + {-1, 0, -2} - {0, 1, 0} (
               CloudObject`Private`tensionnormal$/
               CloudObject`Private`forcefactor$), {
               CloudObject`Private`R0$ Cos[Pi/2], CloudObject`Private`lac0$, 
                CloudObject`Private`R0$ Sin[Pi/2]} + {-1, 0, -2}}]], 
           If[CloudObject`Private`tensionnormal$ > 0, 
            
            Arrow[{{CloudObject`Private`R0$ Cos[Pi], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[Pi]} + {-1, 0, -2}, {
               CloudObject`Private`R0$ Cos[Pi], CloudObject`Private`lac0$, 
                CloudObject`Private`R0$ Sin[Pi]} + {-1, 
               0, -2} + {0, 1, 0} (CloudObject`Private`tensionnormal$/
                CloudObject`Private`forcefactor$)}], 
            
            Arrow[{{CloudObject`Private`R0$ Cos[Pi], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[Pi]} + {-1, 0, -2} - {0, 1, 0} (
               CloudObject`Private`tensionnormal$/
               CloudObject`Private`forcefactor$), {
               CloudObject`Private`R0$ Cos[Pi], CloudObject`Private`lac0$, 
                CloudObject`Private`R0$ Sin[Pi]} + {-1, 0, -2}}]], 
           If[CloudObject`Private`tensionnormal$ > 0, 
            
            Arrow[{{CloudObject`Private`R0$ Cos[(-Pi)/2], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-Pi)/2]} + {-1, 0, -2}, {
               CloudObject`Private`R0$ Cos[(-Pi)/2], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-Pi)/2]} + {-1, 
               0, -2} + {0, 1, 0} (CloudObject`Private`tensionnormal$/
                CloudObject`Private`forcefactor$)}], 
            Arrow[{{
               CloudObject`Private`R0$ Cos[(-Pi)/2], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-Pi)/2]} + {-1, 0, -2} - {0, 1, 0} (
               CloudObject`Private`tensionnormal$/
               CloudObject`Private`forcefactor$), {
               CloudObject`Private`R0$ Cos[(-Pi)/2], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-Pi)/2]} + {-1, 0, -2}}]], 
           If[CloudObject`Private`tensionnormal$ > 0, 
            
            Arrow[{{CloudObject`Private`R0$ Cos[Pi/4], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[Pi/4]} + {-1, 0, -2}, {
               CloudObject`Private`R0$ Cos[Pi/4], CloudObject`Private`lac0$, 
                CloudObject`Private`R0$ Sin[Pi/4]} + {-1, 
               0, -2} + {0, 1, 0} (CloudObject`Private`tensionnormal$/
                CloudObject`Private`forcefactor$)}], 
            
            Arrow[{{CloudObject`Private`R0$ Cos[Pi/4], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[Pi/4]} + {-1, 0, -2} - {0, 1, 0} (
               CloudObject`Private`tensionnormal$/
               CloudObject`Private`forcefactor$), {
               CloudObject`Private`R0$ Cos[Pi/4], CloudObject`Private`lac0$, 
                CloudObject`Private`R0$ Sin[Pi/4]} + {-1, 0, -2}}]], 
           If[CloudObject`Private`tensionnormal$ > 0, 
            
            Arrow[{{CloudObject`Private`R0$ Cos[3 (Pi/4)], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[3 (Pi/4)]} + {-1, 0, -2}, {
               CloudObject`Private`R0$ Cos[3 (Pi/4)], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[3 (Pi/4)]} + {-1, 
               0, -2} + {0, 1, 0} (CloudObject`Private`tensionnormal$/
                CloudObject`Private`forcefactor$)}], 
            
            Arrow[{{CloudObject`Private`R0$ Cos[3 (Pi/4)], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[3 (Pi/4)]} + {-1, 0, -2} - {0, 1, 0} (
               CloudObject`Private`tensionnormal$/
               CloudObject`Private`forcefactor$), {
               CloudObject`Private`R0$ Cos[3 (Pi/4)], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[3 (Pi/4)]} + {-1, 0, -2}}]], 
           If[CloudObject`Private`tensionnormal$ > 0, 
            Arrow[{{
               CloudObject`Private`R0$ Cos[(-Pi)/4], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-Pi)/4]} + {-1, 0, -2}, {
               CloudObject`Private`R0$ Cos[(-Pi)/4], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-Pi)/4]} + {-1, 
               0, -2} + {0, 1, 0} (CloudObject`Private`tensionnormal$/
                CloudObject`Private`forcefactor$)}], 
            
            Arrow[{{CloudObject`Private`R0$ Cos[(-Pi)/4], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-Pi)/4]} + {-1, 0, -2} - {0, 1, 0} (
               CloudObject`Private`tensionnormal$/
               CloudObject`Private`forcefactor$), {
               CloudObject`Private`R0$ Cos[(-Pi)/4], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-Pi)/4]} + {-1, 0, -2}}]], 
           If[CloudObject`Private`tensionnormal$ > 0, 
            
            Arrow[{{CloudObject`Private`R0$ Cos[(-3) (Pi/4)], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-3) (Pi/4)]} + {-1, 0, -2}, {
               CloudObject`Private`R0$ Cos[(-3) (Pi/4)], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-3) (Pi/4)]} + {-1, 
               0, -2} + {0, 1, 0} (CloudObject`Private`tensionnormal$/
                CloudObject`Private`forcefactor$)}], 
            
            Arrow[{{CloudObject`Private`R0$ Cos[(-3) (Pi/4)], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-3) (Pi/4)]} + {-1, 0, -2} - {0, 1, 0} (
               CloudObject`Private`tensionnormal$/
               CloudObject`Private`forcefactor$), {
               CloudObject`Private`R0$ Cos[(-3) (Pi/4)], 
                CloudObject`Private`lac0$, CloudObject`Private`R0$ 
                Sin[(-3) (Pi/4)]} + {-1, 0, -2}}]], Black, Dashed, 
           Thickness[0.01], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-1, 0, -2} - {
             CloudObject`Private`R0$, 0, 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1, 0, -2} + {
              CloudObject`Private`R0$, 0, 0}}], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-1, 0, -2} - {
             0, 0, CloudObject`Private`R0$}, {
              0, CloudObject`Private`lac0$, 0} + {-1, 0, -2} + {
              0, 0, CloudObject`Private`R0$}}]}; CloudObject`Private`dwf11$ = {
           Opacity[CloudObject`Private`inf$$ CloudObject`Private`sup$$], 
           LightGray, 
           
           Cylinder[{{0, 0, 0} + {-1.5, 0.5, -2.2}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2}}, 
            CloudObject`Private`R0$], Black, 
           PointSize[0.05], 
           
           Point[{CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-1.5, 0.5, -2.2}], 
           Text[
           "A", {2 CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-1.5, 0.5, -2.2}], 
           Text[
           "Normal Stress Due to Bending", {
             0, CloudObject`Private`lac0$, 2 CloudObject`Private`R0$} + {-1.5,
              0.5, -2.2}], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} - {
             CloudObject`Private`R0$ CloudObject`Private`xportionmoment, 0, 
              CloudObject`Private`R0$ CloudObject`Private`zportionmoment}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} + {
              CloudObject`Private`R0$ CloudObject`Private`xportionmoment, 0, 
               CloudObject`Private`R0$ CloudObject`Private`zportionmoment}}], 
           Blue, 
           Arrowheads[0.05], 
           Thickness[0.01], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} - {
             CloudObject`Private`R0$ CloudObject`Private`xportionstress, 0, 
              CloudObject`Private`R0$ CloudObject`Private`zportionstress}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} - {
             CloudObject`Private`R0$ CloudObject`Private`xportionstress, 0, 
              CloudObject`Private`R0$ CloudObject`Private`zportionstress} + {
              0, CloudObject`Private`tensionbendmax$/
               CloudObject`Private`normalbendfactor, 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[0.1 Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[0.1 Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[0.1 Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[0.1 Pi]}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[0.1 Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[0.1 Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[0.1 Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[0.1 Pi]} + {
              0, Cos[0.1 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[0.2 Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[0.2 Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[0.2 Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[0.2 Pi]}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[0.2 Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[0.2 Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[0.2 Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[0.2 Pi]} + {
              0, Cos[0.2 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[0.3 Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[0.3 Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[0.3 Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[0.3 Pi]}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[0.3 Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[0.3 Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[0.3 Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[0.3 Pi]} + {
              0, Cos[0.3 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[0.4 Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[0.4 Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[0.4 Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[0.4 Pi]}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[0.4 Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[0.4 Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[0.4 Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[0.4 Pi]} + {
              0, Cos[0.4 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[(-0.1) Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[(-0.1) Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[(-0.1) Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[(-0.1) Pi]}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[(-0.1) Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[(-0.1) Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[(-0.1) Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[(-0.1) Pi]} + {
              0, 
               Cos[(-0.1) Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[(-0.2) Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[(-0.2) Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[(-0.2) Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[(-0.2) Pi]}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[(-0.2) Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[(-0.2) Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[(-0.2) Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[(-0.2) Pi]} + {
              0, Cos[0.2 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[(-0.3) Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[(-0.3) Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[(-0.3) Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[(-0.3) Pi]}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[(-0.3) Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[(-0.3) Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[(-0.3) Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[(-0.3) Pi]} + {
              0, Cos[0.3 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[(-0.4) Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[(-0.4) Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[(-0.4) Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[(-0.4) Pi]}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} - {(CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) 
               Cos[(-0.4) Pi] + (CloudObject`Private`R0$ 
                CloudObject`Private`zportionstress) Sin[(-0.4) Pi], 
              0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress) 
               Cos[(-0.4) Pi] - (CloudObject`Private`R0$ 
               CloudObject`Private`xportionstress) Sin[(-0.4) Pi]} + {
              0, Cos[0.4 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} + {
              CloudObject`Private`R0$ CloudObject`Private`xportionstress, 0, 
               CloudObject`Private`R0$ CloudObject`Private`zportionstress} + {
              0, CloudObject`Private`tensionbendmax$/
               CloudObject`Private`normalbendfactor, 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} + {
              CloudObject`Private`R0$ CloudObject`Private`xportionstress, 0, 
               CloudObject`Private`R0$ CloudObject`Private`zportionstress}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[0.1 Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[0.1 Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[0.1 Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[0.1 Pi]} + {
              0, Cos[0.1 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[0.1 Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[0.1 Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[0.1 Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[0.1 Pi]}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[0.2 Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[0.2 Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[0.2 Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[0.2 Pi]} + {
              0, Cos[0.2 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[0.2 Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[0.2 Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[0.2 Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[0.2 Pi]}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[0.3 Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[0.3 Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[0.3 Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[0.3 Pi]} + {
              0, Cos[0.3 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[0.3 Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[0.3 Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[0.3 Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[0.3 Pi]}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[0.4 Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[0.4 Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[0.4 Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[0.4 Pi]} + {
              0, Cos[0.4 Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[0.4 Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[0.4 Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[0.4 Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[0.4 Pi]}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[(-0.1) Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[(-0.1) Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[(-0.1) Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[(-0.1) Pi]} + {
              0, Cos[(-0.1) Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[(-0.1) Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[(-0.1) Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[(-0.1) Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[(-0.1) Pi]}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[(-0.2) Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[(-0.2) Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[(-0.2) Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[(-0.2) Pi]} + {
              0, Cos[(-0.2) Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[(-0.2) Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[(-0.2) Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[(-0.2) Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[(-0.2) Pi]}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[(-0.3) Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[(-0.3) Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[(-0.3) Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[(-0.3) Pi]} + {
              0, Cos[(-0.3) Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[(-0.3) Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[(-0.3) Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[(-0.3) Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[(-0.3) Pi]}}], 
           
           Arrow[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[(-0.4) Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[(-0.4) Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[(-0.4) Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[(-0.4) Pi]} + {
              0, Cos[(-0.4) Pi] (CloudObject`Private`tensionbendmax$/
                CloudObject`Private`normalbendfactor), 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 
              0.5, -2.2} + {(CloudObject`Private`R0$ 
                 CloudObject`Private`xportionstress) 
                Cos[(-0.4) Pi] + (CloudObject`Private`R0$ 
                 CloudObject`Private`zportionstress) Sin[(-0.4) Pi], 
               0, (CloudObject`Private`R0$ CloudObject`Private`zportionstress)
                  Cos[(-0.4) Pi] - (CloudObject`Private`R0$ 
                CloudObject`Private`xportionstress) Sin[(-0.4) Pi]}}], Black, 
           Dashed, 
           Thickness[0.01], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} - {
             CloudObject`Private`R0$, 0, 0}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} + {
              CloudObject`Private`R0$, 0, 0}}], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} - {
             0, 0, CloudObject`Private`R0$}, {
              0, CloudObject`Private`lac0$, 0} + {-1.5, 0.5, -2.2} + {
              0, 0, CloudObject`Private`R0$}}]}; CloudObject`Private`dwf12$ = {
           Opacity[CloudObject`Private`inf$$ CloudObject`Private`sup$$], 
           LightGray, 
           
           Cylinder[{{0, 0, 0} + {-2, 1, -2.4}, {
              0, CloudObject`Private`lac0$, 0} + {-2, 1, -2.4}}, 
            CloudObject`Private`R0$], Black, 
           PointSize[0.05], 
           
           Point[{CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-2, 1, -2.4}], 
           Text[
           "A", {2 CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-2, 1, -2.4}], 
           Text[
           "Shear Stress Due to Transverse Loading", {
             0, CloudObject`Private`lac0$, 2 CloudObject`Private`R0$} + {-2, 
              1, -2.4}], Green, 
           Arrowheads[0.05], 
           Thickness[0.01], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{0.2 CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$,
                0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {
              0.2 CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{0.4 CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$,
                0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {
              0.4 CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{0.6 CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$,
                0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {
              0.6 CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{0.8 CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$,
                0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {
              0.8 CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{1. CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {
              1. CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{(-0.2) CloudObject`Private`R0$, 1.1 
               CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {(-0.2) 
               CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{(-0.4) CloudObject`Private`R0$, 1.1 
               CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {(-0.4) 
               CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{(-0.6) CloudObject`Private`R0$, 1.1 
               CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {(-0.6) 
               CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{(-0.8) CloudObject`Private`R0$, 1.1 
               CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {(-0.8) 
               CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} + {
              0, 0, (CloudObject`Private`shearbend/2)/
               CloudObject`Private`shearbendfactor}}], 
           
           Arrow[{{-CloudObject`Private`R0$, 1.1 CloudObject`Private`lac0$, 
               0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}, {-CloudObject`Private`R0$,
                1.1 CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} - {
             0, 0, (CloudObject`Private`shearbend/2)/
              CloudObject`Private`shearbendfactor}}], Black, Dashed, 
           Thickness[0.01], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} - {
             CloudObject`Private`R0$, 0, 0}, {
              0, CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} + {
              CloudObject`Private`R0$, 0, 0}}], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} - {
             0, 0, CloudObject`Private`R0$}, {
              0, CloudObject`Private`lac0$, 0} + {-2, 1, -2.4} + {
              0, 0, CloudObject`Private`R0$}}]}; CloudObject`Private`dwf13$ = {
           Opacity[CloudObject`Private`inf$$ CloudObject`Private`sup$$], 
           LightGray, 
           
           Cylinder[{{0, 0, 0} + {-2.5, 1.5, -2.6}, {
              0, CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6}}, 
            CloudObject`Private`R0$], Black, 
           PointSize[0.05], 
           
           Point[{CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-2.5, 1.5, -2.6}], 
           Text[
           "A", {2 CloudObject`Private`R0$, CloudObject`Private`lac0$, 
              0} + {-2.5, 1.5, -2.6}], 
           Text[
           "Shear Stress Due to Torsion", {
             0, CloudObject`Private`lac0$, 2 CloudObject`Private`R0$} + {-2.5,
              1.5, -2.6}], Purple, 
           Arrowheads[0.05], 
           Thickness[0.01], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} - {
             CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - {
             CloudObject`Private`R0$, 0, CloudObject`Private`sheartorsion/
              CloudObject`Private`sheartorsionfactor}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} - {
             0.8 CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - {
             0.8 CloudObject`Private`R0$, 0, 
              0.8 (CloudObject`Private`sheartorsion/
               CloudObject`Private`sheartorsionfactor)}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} - {
             0.6 CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - {
             0.6 CloudObject`Private`R0$, 0, 
              0.6 (CloudObject`Private`sheartorsion/
               CloudObject`Private`sheartorsionfactor)}}], 
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} - {
             0.4 CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - {
             0.4 CloudObject`Private`R0$, 0, 
              0.4 (CloudObject`Private`sheartorsion/
               CloudObject`Private`sheartorsionfactor)}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} - {
             0.2 CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - {
             0.2 CloudObject`Private`R0$, 0, 
              0.2 (CloudObject`Private`sheartorsion/
               CloudObject`Private`sheartorsionfactor)}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} + {CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + {
              CloudObject`Private`R0$, 0, CloudObject`Private`sheartorsion/
               CloudObject`Private`sheartorsionfactor}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} + {0.8 CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + {
              0.8 CloudObject`Private`R0$, 0, 
               0.8 (CloudObject`Private`sheartorsion/
                CloudObject`Private`sheartorsionfactor)}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} + {0.6 CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + {
              0.6 CloudObject`Private`R0$, 0, 
               0.6 (CloudObject`Private`sheartorsion/
                CloudObject`Private`sheartorsionfactor)}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} + {0.4 CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + {
              0.4 CloudObject`Private`R0$, 0, 
               0.4 (CloudObject`Private`sheartorsion/
                CloudObject`Private`sheartorsionfactor)}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} + {0.2 CloudObject`Private`R0$, 0, 0}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + {
              0.2 CloudObject`Private`R0$, 0, 
               0.2 (CloudObject`Private`sheartorsion/
                CloudObject`Private`sheartorsionfactor)}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} + {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} + {(-CloudObject`Private`sheartorsion)/
               CloudObject`Private`sheartorsionfactor, 0, 
               CloudObject`Private`R0$}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + 
             0.8 {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + 
             0.8 {(-CloudObject`Private`sheartorsion)/
                CloudObject`Private`sheartorsionfactor, 0, 
                CloudObject`Private`R0$}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + 
             0.6 {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + 
             0.6 {(-CloudObject`Private`sheartorsion)/
                CloudObject`Private`sheartorsionfactor, 0, 
                CloudObject`Private`R0$}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + 
             0.4 {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + 
             0.4 {(-CloudObject`Private`sheartorsion)/
                CloudObject`Private`sheartorsionfactor, 0, 
                CloudObject`Private`R0$}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + 
             0.2 {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + 
             0.2 {(-CloudObject`Private`sheartorsion)/
                CloudObject`Private`sheartorsionfactor, 0, 
                CloudObject`Private`R0$}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} - {
             0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 
              1.5, -2.6} - {(-CloudObject`Private`sheartorsion)/
              CloudObject`Private`sheartorsionfactor, 0, 
              CloudObject`Private`R0$}}], 
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - 
             0.8 {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - 
             0.8 {(-CloudObject`Private`sheartorsion)/
               CloudObject`Private`sheartorsionfactor, 0, 
               CloudObject`Private`R0$}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - 
             0.6 {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - 
             0.6 {(-CloudObject`Private`sheartorsion)/
               CloudObject`Private`sheartorsionfactor, 0, 
               CloudObject`Private`R0$}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - 
             0.4 {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - 
             0.4 {(-CloudObject`Private`sheartorsion)/
               CloudObject`Private`sheartorsionfactor, 0, 
               CloudObject`Private`R0$}}], 
           
           Arrow[{{0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - 
             0.2 {0, 0, CloudObject`Private`R0$}, {
              0, 1.1 CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - 
             0.2 {(-CloudObject`Private`sheartorsion)/
               CloudObject`Private`sheartorsionfactor, 0, 
               CloudObject`Private`R0$}}], Black, Dashed, 
           Thickness[0.01], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - {
             CloudObject`Private`R0$, 0, 0}, {
              0, CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + {
              CloudObject`Private`R0$, 0, 0}}], 
           
           Line[{{0, CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} - {
             0, 0, CloudObject`Private`R0$}, {
              0, CloudObject`Private`lac0$, 0} + {-2.5, 1.5, -2.6} + {
              0, 0, CloudObject`Private`R0$}}]}; CloudObject`Private`dwf14$ = {
           Opacity[CloudObject`Private`cub$$], LightBlue, 
           
           Rectangle[{-CloudObject`Private`R0$, -CloudObject`Private`R0$}, {
            CloudObject`Private`R0$, CloudObject`Private`R0$}], Black, 
           Thickness[0.0075], 
           Arrowheads[0.05], 
           Arrow[{{0, 0}, {0.7 CloudObject`Private`R0$, 0}}], 
           Arrow[{{0, 0}, {0, 0.7 CloudObject`Private`R0$}}], 
           Text[
           "A", {(-0.1) CloudObject`Private`R0$, (-0.1) 
             CloudObject`Private`R0$}], 
           Text[
           "y\!\(\*\nStyleBox[\"'\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {0.8 CloudObject`Private`R0$, 0}], 
           Text["z'", {0, 0.8 CloudObject`Private`R0$}], 
           Thickness[0.015], 
           Arrowheads[0.075], 
           If[CloudObject`Private`normalstress > 0, 
            
            Arrow[{{CloudObject`Private`R0$, 0}, {
               CloudObject`Private`R0$, 0} + {
               CloudObject`Private`normalstress/
                CloudObject`Private`normalfactor, 0}}], 
            
            Arrow[{{CloudObject`Private`R0$, 0} - {
              CloudObject`Private`normalstress/
               CloudObject`Private`normalfactor, 0}, {
              CloudObject`Private`R0$, 0}}]], 
           If[CloudObject`Private`normalstress > 0, 
            
            Arrow[{{-CloudObject`Private`R0$, 
               0}, {-CloudObject`Private`R0$, 0} - {
              CloudObject`Private`normalstress/
               CloudObject`Private`normalfactor, 0}}], 
            
            Arrow[{{-CloudObject`Private`R0$, 0} + {
               CloudObject`Private`normalstress/
                CloudObject`Private`normalfactor, 0}, {-
               CloudObject`Private`R0$, 0}}]], 
           If[Abs[CloudObject`Private`shearstress] > 0, 
            
            Arrow[{{1.2 CloudObject`Private`R0$, 0} + {
               0, ((-CloudObject`Private`shearstress)/
                 CloudObject`Private`shearfactor)/2}, {
               1.2 CloudObject`Private`R0$, 0} + {
               0, (CloudObject`Private`shearstress/
                 CloudObject`Private`shearfactor)/2}}]], 
           If[Abs[CloudObject`Private`shearstress] > 0, 
            
            Arrow[{{0, 1.2 
                CloudObject`Private`R0$} + {((-
                  CloudObject`Private`shearstress)/
                 CloudObject`Private`shearfactor)/2, 0}, {
               0, 1.2 CloudObject`Private`R0$} + {(
                 CloudObject`Private`shearstress/
                 CloudObject`Private`shearfactor)/2, 0}}]], 
           If[Abs[CloudObject`Private`shearstress] > 0, 
            Arrow[{{(-1.2) CloudObject`Private`R0$, 0} - {
              0, ((-CloudObject`Private`shearstress)/
                CloudObject`Private`shearfactor)/
               2}, {(-1.2) CloudObject`Private`R0$, 0} - {
              0, (CloudObject`Private`shearstress/
                CloudObject`Private`shearfactor)/2}}]], 
           If[Abs[CloudObject`Private`shearstress] > 0, 
            
            Arrow[{{0, (-1.2) 
                CloudObject`Private`R0$} - {((-
                 CloudObject`Private`shearstress)/
                CloudObject`Private`shearfactor)/2, 0}, {
               0, (-1.2) CloudObject`Private`R0$} - {(
                CloudObject`Private`shearstress/
                CloudObject`Private`shearfactor)/2, 0}}]], 
           
           Line[{{5 CloudObject`Private`R0$, -CloudObject`Private`R0$}, {
             5 CloudObject`Private`R0$, CloudObject`Private`R0$}}]}; 
        CloudObject`Private`dwf15$ = {
           Opacity[CloudObject`Private`cub$$], Black, 
           Thickness[0.0075], 
           Arrowheads[0.05], 
           
           Line[{{(-3) CloudObject`Private`R0$, (-2.5) 
              CloudObject`Private`R0$}, {(-3) CloudObject`Private`R0$, 2.5 
              CloudObject`Private`R0$}}], 
           
           Line[{{(-3) CloudObject`Private`R0$, 2.5 
              CloudObject`Private`R0$}, {(-2.8) CloudObject`Private`R0$, 2.5 
              CloudObject`Private`R0$}}], 
           
           Line[{{(-3) CloudObject`Private`R0$, (-2.5) 
              CloudObject`Private`R0$}, {(-2.8) 
              CloudObject`Private`R0$, (-2.5) CloudObject`Private`R0$}}], 
           
           Line[{{3.75 CloudObject`Private`R0$, (-2.5) 
              CloudObject`Private`R0$}, {
             3.75 CloudObject`Private`R0$, 2.5 CloudObject`Private`R0$}}], 
           
           Line[{{3.55 CloudObject`Private`R0$, (-2.5) 
              CloudObject`Private`R0$}, {
             3.75 CloudObject`Private`R0$, (-2.5) CloudObject`Private`R0$}}], 
           
           Line[{{3.55 CloudObject`Private`R0$, 2.5 
              CloudObject`Private`R0$}, {
             3.75 CloudObject`Private`R0$, 2.5 CloudObject`Private`R0$}}], 
           Text[
           "\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\"]\)", {(-2.5) 
             CloudObject`Private`R0$, 2 CloudObject`Private`R0$}], 
           Text[
           "\!\(\*\nStyleBox[\"0\",\nFontWeight->\"Bold\"]\)", {(-0.5) 
             CloudObject`Private`R0$, 2 CloudObject`Private`R0$}], 
           Text[
           "0", {2.5 CloudObject`Private`R0$, 2 CloudObject`Private`R0$}], 
           Text["0", {(-2.5) CloudObject`Private`R0$, 0}], 
           Text[
            Style[
             Round[CloudObject`Private`normalstress, 0.01], FontSize -> 
             12], {(-0.5) CloudObject`Private`R0$, 0}], 
           Text[
            Style[
             Round[CloudObject`Private`shearstress, 0.01], FontSize -> 12], {
            2.5 CloudObject`Private`R0$, 0}], 
           Text[
           "0", {(-2.5) CloudObject`Private`R0$, (-2) 
             CloudObject`Private`R0$}], 
           Text[
            Style[
             Round[CloudObject`Private`shearstress, 0.01], FontSize -> 
             12], {(-0.5) CloudObject`Private`R0$, (-2) 
             CloudObject`Private`R0$}], 
           Text[
           "0", {2.5 CloudObject`Private`R0$, (-2) CloudObject`Private`R0$}]}; 
        CloudObject`Private`dwf16 = {
           Opacity[CloudObject`Private`inf$$ CloudObject`Private`sup$$]}; 
        CloudObject`Private`dw1$ = 
         Graphics3D[{
           CloudObject`Private`dwf1$, CloudObject`Private`dwf2$, 
            CloudObject`Private`dwf3$, CloudObject`Private`dwf4$, 
            CloudObject`Private`dwf5$, CloudObject`Private`dwf6$, 
            CloudObject`Private`dwf7$}, CloudObject`Private`settings1$, 
           PreserveImageOptions -> CloudObject`Private`reset1]; 
        CloudObject`Private`dw2$ = 
         Graphics3D[{CloudObject`Private`dwf8$}, 
           CloudObject`Private`settings2$, PreserveImageOptions -> 
           CloudObject`Private`reset1]; 
        CloudObject`Private`dw3$ = 
         Graphics3D[{CloudObject`Private`dwf10$}, 
           CloudObject`Private`settings3$, PreserveImageOptions -> 
           CloudObject`Private`reset1]; 
        CloudObject`Private`dw4$ = 
         Graphics3D[{CloudObject`Private`dwf11$}, 
           CloudObject`Private`settings4$, PreserveImageOptions -> 
           CloudObject`Private`reset1]; 
        CloudObject`Private`dw5$ = 
         Graphics3D[{CloudObject`Private`dwf12$}, 
           CloudObject`Private`settings5$, PreserveImageOptions -> 
           CloudObject`Private`reset1]; 
        CloudObject`Private`dw6$ = 
         Graphics3D[{CloudObject`Private`dwf13$}, 
           CloudObject`Private`settings6$, PreserveImageOptions -> 
           CloudObject`Private`reset1]; CloudObject`Private`dw7$ = {
           If[Abs[CloudObject`Private`torque$] > 0, 
            
            ParametricPlot3D[{(CloudObject`Private`R0$ 
                CloudObject`Private`torqueratio) 
               Cos[CloudObject`Private`\[Phi]], 
               0, (CloudObject`Private`R0$ CloudObject`Private`torqueratio) 
               Sin[CloudObject`Private`\[Phi]]} + {-1, 0, -1} + {
              0, 2 CloudObject`Private`lac0$, 0}, {
             CloudObject`Private`\[Phi], (-Pi)/1.2, Pi/1.2}, Boxed -> False, 
             ViewPoint -> CloudObject`Private`view, PlotStyle -> Purple]], 
           If[Abs[CloudObject`Private`bendmomentfy$] > 0, 
            
            ParametricPlot3D[{(0.75 CloudObject`Private`R0$) 
               Cos[CloudObject`Private`\[Phi]], (0.75 CloudObject`Private`R0$)
                 Sin[CloudObject`Private`\[Phi]], 0} + {-1, 0, -1} + {
              0, 3 CloudObject`Private`lac0$, 0}, {
             CloudObject`Private`\[Phi], Pi/2 - 
              Pi (CloudObject`Private`bendmomentfyratio/1.2), Pi/2 + 
              Pi (CloudObject`Private`bendmomentfyratio/1.2)}, Boxed -> False,
              ViewPoint -> CloudObject`Private`view, PlotStyle -> Blue]], 
           If[Abs[CloudObject`Private`bendmomentfz$] > 0, 
            
            ParametricPlot3D[{
              0, (0.75 CloudObject`Private`R0$) 
               Cos[CloudObject`Private`\[Phi]], (0.75 CloudObject`Private`R0$)
                 Sin[CloudObject`Private`\[Phi]]} + {-1, 0, -1} + {
              0, 4 CloudObject`Private`lac0$, 0}, {
             CloudObject`Private`\[Phi], (-Pi) (
               CloudObject`Private`bendmomentfzratio/1.2), 
              Pi (CloudObject`Private`bendmomentfzratio/1.2)}, Boxed -> False,
              ViewPoint -> CloudObject`Private`view, PlotStyle -> Blue]]}; 
        CloudObject`Private`dw8$ = 
         Graphics[{CloudObject`Private`dwf14$}, 
           CloudObject`Private`settings7$]; 
        CloudObject`Private`dw9$ = 
         Graphics[{CloudObject`Private`dwf15$}, 
           CloudObject`Private`settings8$]; Column[{
           If[CloudObject`Private`inf$$ > 0, 
            If[CloudObject`Private`sup$$ > 0, 
             Row[{
               Show[CloudObject`Private`dw1$], 
               Column[{
                 Row[{
                   Show[CloudObject`Private`dw2$, CloudObject`Private`dw7$], 
                   Spacer[50], 
                   Show[CloudObject`Private`dw8$], 
                   Spacer[50], 
                   Show[CloudObject`Private`dw9$]}], 
                 Row[{
                   Show[CloudObject`Private`dw3$], 
                   Show[CloudObject`Private`dw4$], 
                   Show[CloudObject`Private`dw5$], 
                   Show[CloudObject`Private`dw6$]}]}]}], 
             Row[{
               Show[CloudObject`Private`dw1$], 
               Show[CloudObject`Private`dw2$, CloudObject`Private`dw7$]}]], 
            Show[CloudObject`Private`dw1$]], 
           If[CloudObject`Private`inf$$ > 0, 
            If[CloudObject`Private`sup$$ > 0, 
             Column[{
               Text[
                
                Grid[{{"Internal Forces on Section A", SpanFromLeft}, {
                  "\!\(\*\nStyleBox[\"Axial\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"Loadings\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"[\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"N\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., \
0., 0.]]\)", 
                   "\!\(\*\nStyleBox[\"Bending\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"Moment\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"in\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"-\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Plane\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"[\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"N\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"m\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
                   "\!\(\*\nStyleBox[\"Bending\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"Moment\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"in\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"-\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Plane\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"[\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"N\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"m\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
                   "\!\(\*\nStyleBox[\"Transverse\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\"Loading\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., \
0.]]\)\!\(\*\nStyleBox[\"N\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
1., 0.]]\)\!\(\*\nStyleBox[\"]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 1., 0.]]\)", 
                   "\!\(\*\nStyleBox[\"Torque\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"[\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"N\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"\[CenterDot]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"m\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)"}, 
                  
                  Round[{CloudObject`Private`fy$, 
                    CloudObject`Private`bendmomentfy$, 
                    CloudObject`Private`bendmomentfz$, 
                    CloudObject`Private`fz$, CloudObject`Private`torque$}, 
                   0.01]}, ItemSize -> 22, Frame -> All, Background -> {None, {
                    Lighter[Gray, 0.95]}}]], 
               Text[
                
                Grid[{{"Stress at Point A", SpanFromLeft}, {
                  "\!\(\*\nStyleBox[\"Normal\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"Stress\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"due\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., \
0., 0.]]\)\!\(\*\nStyleBox[\"to\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"Axial\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"Loadings\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"[\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., \
0., 0.]]\)\!\(\*\nStyleBox[\"MPa\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"]\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[1., 0., 0.]]\)", 
                   "\!\(\*\nStyleBox[\"Normal\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"Stress\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Due\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"to\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"Bending\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\"MPa\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"]\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
                   "\!\(\*\nStyleBox[\"Shear\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\"Stress\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\n\
StyleBox[\"Due\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
1., 0.]]\)\!\(\*\nStyleBox[\"to\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\"Transverse\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\n\
StyleBox[\"Loading\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., \
0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
1., 0.]]\)\!\(\*\nStyleBox[\"[\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\"MPa\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\"]\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)", 
                   "\!\(\*\nStyleBox[\"Shear\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"Stress\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"Due\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"to\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"Torsion\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"[\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"MPa\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)"}, 
                  Round[{
                   CloudObject`Private`tensionnormal$, 
                    CloudObject`Private`tensionbendfy, 
                    CloudObject`Private`shearbend, 
                    CloudObject`Private`sheartorsion}, 0.01]}, ItemSize -> 
                 27.7, Frame -> All, Background -> {None, {
                    Lighter[Gray, 0.95]}}]]}], 
             Text[
              
              Grid[{{"Internal Forces on Section A", SpanFromLeft}, {
                "\!\(\*\nStyleBox[\"Axial\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"Loadings\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\nStyleBox[\"[\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., 0.]]\)\!\(\*\n\
StyleBox[\"N\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0., \
0.]]\)\!\(\*\nStyleBox[\"]\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., \
0., 0.]]\)", 
                 "\!\(\*\nStyleBox[\"Bending\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"Moment\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"in\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"-\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Plane\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"[\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"N\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"m\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
                 "\!\(\*\nStyleBox[\"Bending\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"Moment\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"in\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\
\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"-\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\" \",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"Plane\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., \
1.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
0., 1.]]\)\!\(\*\nStyleBox[\"[\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"N\",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"\[CenterDot]\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\nStyleBox[\"m\
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)\!\(\*\n\
StyleBox[\"]\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 0., 1.]]\)", 
                 "\!\(\*\nStyleBox[\"Transverse\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Bold\
\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\"Loading\",\n\
FontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\nStyleBox[\" \
\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., 0.]]\)\!\(\*\n\
StyleBox[\"[\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., 1., \
0.]]\)\!\(\*\nStyleBox[\"N\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0., \
1., 0.]]\)\!\(\*\nStyleBox[\"]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0., 1., 0.]]\)", 
                 "\!\(\*\nStyleBox[\"Torque\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"[\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"N\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"\[CenterDot]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"m\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)\!\(\*\n\
StyleBox[\"]\",\nFontWeight->\"Bold\",\n\
FontColor->RGBColor[0.5019607843137255, 0., 0.5019607843137255]]\)"}, 
                
                Round[{CloudObject`Private`fy$, 
                  CloudObject`Private`bendmomentfy$, 
                  CloudObject`Private`bendmomentfz$, CloudObject`Private`fz$, 
                  CloudObject`Private`torque$}, 0.01]}, ItemSize -> 22, Frame -> 
               All, Background -> {None, {
                  Lighter[Gray, 0.95]}}]]]]}]], 
      "Specifications" :> {{{CloudObject`Private`lcd$$, 1, 
          Row[{"Length of CD [m]", 
            Spacer[60]}]}, 0.5, 2, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 1}, {{CloudObject`Private`lbd$$, 1, 
          Row[{"Length of BD [m]", 
            Spacer[60]}]}, 0.01, 2, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 2}, {{CloudObject`Private`R$$, 0.05, 
          Row[{"Radius of the rod [m]", 
            Spacer[40]}]}, 0.05, 0.1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 3}, {{CloudObject`Private`mf$$, 500, 
          Row[{"Magnitude of Force[N]", 
            Spacer[30]}]}, 0.1, 500, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 4}, {{CloudObject`Private`df$$, 30, 
          Row[{"Direction of Force", 
            Spacer[55]}]}, -180, 180, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 5}, {{CloudObject`Private`lac$$, 0.5, 
          Row[{"Position of Point A [m]", 
            Spacer[30]}]}, 0, 
         Dynamic[0.99 CloudObject`Private`lcd$$], ImageSize -> Small, 
         Appearance -> "Labeled", ControlPlacement -> 6}, {{
         CloudObject`Private`inf$$, 0, 
          Row[{"Internal Loadings on Section A", 
            Spacer[52]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 7}, {{CloudObject`Private`sup$$, 0, 
          Row[{"Decomposed Stress on Section A", 
            Spacer[40]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 8}, {{CloudObject`Private`cub$$, 0, 
          Row[{"Stress Cubic at Point A", 
            Spacer[95]}]}, {1 -> "On", 0 -> "off"}, ControlType -> 
         RadioButton, ControlPlacement -> 9}, 
        Grid[{{
           Row[{
             Column[{
               Manipulate`Place[1], 
               Manipulate`Place[2], 
               Manipulate`Place[3]}], 
             Spacer[50], 
             Column[{
               Manipulate`Place[4], 
               Manipulate`Place[5], 
               Manipulate`Place[6]}], 
             Spacer[50], 
             Column[{
               Manipulate`Place[7], 
               Manipulate`Place[8], 
               Manipulate`Place[9]}], 
             Spacer[50], 
             Column[{
               Button[
               "Reset view", CloudObject`Private`reset$$ = True, 
                ImageSize -> {90, 30}]}]}]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}], {{CloudObject`Private`reset$$, False},
          0, ControlType -> None}}, "Options" :> {ControlPlacement -> Top}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1191., {297., 303.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "766ffe05-112e-4a65-9a08-d93f15fadd23"]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[1464, 33, 176, 3, 75, "Text"],
Cell[1643, 38, 148, 4, 30, "Text"],
Cell[1794, 44, 150, 3, 49, "Text"],
Cell[1947, 49, 232, 4, 49, "Text"],
Cell[2182, 55, 101415, 1854, 617, "Output"]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature WuDV3BKKw85m1C1M#rxMdG1H *)
